@@ -3,6 +3,7 @@ from abc import ABC
 from enum import Enum
 import datetime
 import typesystem as ts
+from markupsafe import Markup
 
 from essencia_core.utils import normalize
 
@@ -104,13 +105,15 @@ class Profile(BaseModel):
     cpf = ts.String(allow_blank=True)
     email = ts.String(allow_blank=True)
 
+    @property
     def as_html(self):
         text = '<div><h3>{}</h3><hr><ul>'.format(self.fullname)
         text += '<li>nascimento: {}</li>'.format(self.birthdate)
         text += '<li>idade: {}</li>'.format(self.age_str)
         text += '<li>gênero: {}</li>'.format(self.gender)
         text += '<li>url: {}</li>'.format(self.url)
-        return text
+        text += '</ul></div>'
+        return Markup(text)
 
 
 
